/* XPM */
static char * Xinvest_m_pm[] = {
"32 32 3 1 0 0",
".      s none  m none  c none",
" 	s topShadowColor	m black	c #949494949494",
"X	s iconColor3	m black	c red",
"        ......................  ",
".        .....................  ",
"..        ...................  .",
"...        .................  ..",
"...        ................  ...",
"....        .....XXX......  ....",
".....        ....XXX.....  .....",
"...XXX        ...XXX....XXX.....",
"...XXX        ...XXX....XXX.....",
"...XXX.        ..XXXX..XXXX.....",
"...XXX..        .XXXX. XXXX.....",
"...XXX...        XXXX  XXXX.....",
"...XXX...        XXX  ..XXX.....",
"...XXX....XXX    XXX  ..XXX.....",
"...XXXX...XXX   XXXX ...XXX.....",
"...XXXX...XXX   XXXX....XXX.....",
"...XXXX..XXXX   XXXX....XXXX....",
"...XXX...XXXX  . XXX ...XXXX....",
"..XXXX...XXXX .  XXX  ..XXXX....",
"..XXXX....XXX..  XXX   .XXX.....",
"..XXXX....XXX..  XXX   .XXX.....",
"...XXX....XXX... XXX    XXX.....",
"...XXX... XXX....XXX    XXX.....",
"...XXX..  XXXX....      XXX.....",
"...XXX.  .XXXX....      XXX.....",
"......  ..XXXX.....     XXX.....",
"......  ..XXX.......        ....",
".....  ...XXX........        ...",
"....  ....XXX........        ...",
"...  .................        ..",
"..  ...................        .",
".  .....................        "};
